core/err/exceptions library

Exceptions / Errors

CircuitBreakerOpenException
Thrown by the guard method when the circuit breaker is open due to repeated backend failures.
NetworkReachabilityException
Base class for all network reachability exceptions.
NetworkTimeoutException
Thrown when a network check operation times out.
PoorConnectionException
Thrown by the guard method when the connection quality is below the required minimum.
SecurityException
Thrown by the guard method when a security requirement is not met (e.g., VPN detected).