NetworkReachabilityException class abstract

Base class for all network reachability exceptions.

This class is abstract and cannot be directly instantiated.

It provides a common interface for all network reachability exceptions.

See also NetworkReachabilityException.toString for more information.

Implemented types
Implementers

Constructors

NetworkReachabilityException(String message)
Creates a new NetworkReachabilityException with the given message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with this exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Converts this object to a human-readable string representation.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited