NetworkTimeoutException class

Thrown when a network check operation times out.

Inheritance

Constructors

NetworkTimeoutException(String message)
Creates a new NetworkTimeoutException with the given message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with this exception.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Converts this object to a human-readable string representation.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited