SecurityException class

Thrown by the guard method when a security requirement is not met (e.g., VPN detected).

Inheritance

Constructors

SecurityException(SecurityAlert reason, String message)
Creates a new SecurityException with the given reason and message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with this exception.
finalinherited
reason SecurityAlert
The reason this exception was thrown.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Converts this object to a human-readable string representation.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited