reason property
The reason this exception was thrown.
This is a human-readable string that provides additional information about the security requirement that was not met.
Implementation
final SecurityAlert reason;
The reason this exception was thrown.
This is a human-readable string that provides additional information about the security requirement that was not met.
final SecurityAlert reason;