core/extensions/model_extensions library

Extensions

CaptivePortalStatusCopyWith on CaptivePortalStatus
Extension on CaptivePortalStatus to provide an immutable way to copy the status.
LatencyStatsCopyWith on LatencyStats
Extension on LatencyStats to provide an immutable way to copy stats.
NetworkConfigurationCopyWith on NetworkConfiguration
Extension on NetworkConfiguration to provide an immutable way to copy the config.
NetworkReportCopyWith on NetworkReport
Extension on NetworkReport to provide an immutable way to copy the report.
NetworkStatusCopyWith on NetworkStatus
Extension on NetworkStatus to provide an immutable way to copy the status summary.
NetworkTargetCopyWith on NetworkTarget
Extension on NetworkTarget to provide an immutable way to copy the target definition.
QualityThresholdsCopyWith on QualityThresholds
Extension on QualityThresholds to provide an immutable way to copy the config.
ResilienceConfigCopyWith on ResilienceConfig
Extension on ResilienceConfig to provide an immutable way to copy the config.
SecurityConfigCopyWith on SecurityConfig
Extension on SecurityConfig to provide an immutable way to copy the config.
SecurityFlagsCopyWith on SecurityFlags
Extension on SecurityFlags to provide an immutable way to copy the flags.
SecurityFlagsResultCopyWith on SecurityFlagsResult
Extension on TraceHop to provide an immutable way to copy the hop data. Extension on SecurityFlagsResult to provide an immutable way to copy the result.
TargetReportCopyWith on TargetReport
Extension on TargetReport to provide an immutable way to copy the report for a single target.