LatencyStatsCopyWith extension

Extension on LatencyStats to provide an immutable way to copy stats.

on

Methods

copyWith({BigInt? latencyMs, BigInt? jitterMs, double? packetLossPercent, BigInt? minLatencyMs, BigInt? avgLatencyMs, BigInt? maxLatencyMs, int? stabilityScore}) LatencyStats

Available on LatencyStats, provided by the LatencyStatsCopyWith extension

Creates a copy of LatencyStats with the given fields replaced by the new values.