SecurityConfigCopyWith extension

Extension on SecurityConfig to provide an immutable way to copy the config.

on

Methods

copyWith({bool? blockVpn, bool? detectDnsHijack}) SecurityConfig

Available on SecurityConfig, provided by the SecurityConfigCopyWith extension

Creates a copy of SecurityConfig with the given fields replaced by the new values.