SecurityFlagsCopyWith extension

Extension on SecurityFlags to provide an immutable way to copy the flags.

on

Methods

copyWith({bool? isVpnDetected, bool? isDnsSpoofed, bool? isProxyDetected, String? interfaceName}) SecurityFlags

Available on SecurityFlags, provided by the SecurityFlagsCopyWith extension

Creates a copy of SecurityFlags with the given fields replaced by the new values.