SecurityFlagsResultCopyWith extension

Extension on TraceHop to provide an immutable way to copy the hop data. Extension on SecurityFlagsResult to provide an immutable way to copy the result.

on

Methods

copyWith({bool? isVpnDetected, bool? isDnsSpoofed, bool? isProxyDetected}) SecurityFlagsResult

Available on SecurityFlagsResult, provided by the SecurityFlagsResultCopyWith extension

Creates a copy of SecurityFlagsResult with the given fields replaced by the new values.