SecurityFlagsResultImpl class
- Implemented types
- Available extensions
- Annotations
-
- @sealed
Constructors
- SecurityFlagsResultImpl.frbInternalDcoDecode(List wire)
- SecurityFlagsResultImpl.frbInternalSseDecode(BigInt ptr, int externalSizeOnNative)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interfaceName ↔ String
-
getter/setter pairoverride
- isDisposed → bool
-
Whether the underlying
Arcis disposed.no setterinherited - isDnsSpoofed ↔ bool
-
getter/setter pairoverride
- isProxyDetected ↔ bool
-
getter/setter pairoverride
- isVpnDetected ↔ bool
-
getter/setter pairoverride
- move ← bool?
-
no getterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isVpnDetected, bool? isDnsSpoofed, bool? isProxyDetected}) → SecurityFlagsResult -
Available on SecurityFlagsResult, provided by the SecurityFlagsResultCopyWith extension
Creates a copy of SecurityFlagsResult with the given fields replaced by the new values. -
dispose(
) → void -
Dispose the underlying
Arc.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited