CheckStrategy enum

Defines the strategy used when evaluating multiple network targets.

This strategy determines how the engine decides if the network is "up" when multiple targets are configured.

Inheritance
Available extensions

Values

race → const CheckStrategy

The first target to respond successfully determines the result.

This is the fastest strategy as it doesn't wait for other targets. It's ideal for performance-sensitive applications where any connectivity to a trusted endpoint is sufficient.

consensus → const CheckStrategy

A majority of targets must respond successfully for the check to be considered a success.

This strategy is more robust against localized outages or transient failures of individual endpoints. It is slower than Race because it may wait for multiple responses.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CheckStrategy>
A constant List of the values in this enum, in order of their declaration.