cacheValidityMs property
The duration (in milliseconds) for which a network report is cached.
Rapid consecutive calls will return the cached report to save battery and bandwidth.
Implementation
final BigInt cacheValidityMs;
The duration (in milliseconds) for which a network report is cached.
Rapid consecutive calls will return the cached report to save battery and bandwidth.
final BigInt cacheValidityMs;