checkIntervalMs property
The interval in milliseconds between automatic periodic checks.
Set to 0 to disable periodic background checks and rely on manual triggers.
Implementation
final BigInt checkIntervalMs;
The interval in milliseconds between automatic periodic checks.
Set to 0 to disable periodic background checks and rely on manual triggers.
final BigInt checkIntervalMs;