poor property
Latency at or below this value is considered ConnectionQuality::Poor.
Anything higher is categorized as ConnectionQuality::Unstable or ConnectionQuality::Poor.
Implementation
final BigInt poor;
Latency at or below this value is considered ConnectionQuality::Poor.
Anything higher is categorized as ConnectionQuality::Unstable or ConnectionQuality::Poor.
final BigInt poor;