circuitBreakerThreshold property
The number of consecutive failures of essential targets before the circuit breaker opens.
A value of 0 disables the circuit breaker mechanism.
Implementation
final int circuitBreakerThreshold;
The number of consecutive failures of essential targets before the circuit breaker opens.
A value of 0 disables the circuit breaker mechanism.
final int circuitBreakerThreshold;