criticalPacketLossPrecent property
The packet loss percentage above which the connection is marked as ConnectionQuality::Unstable.
Implementation
final double criticalPacketLossPrecent;
The packet loss percentage above which the connection is marked as ConnectionQuality::Unstable.
final double criticalPacketLossPrecent;