jitterThresholdPercent property

double jitterThresholdPercent
final

The percentage of mean latency that the standard deviation must exceed to be flagged as high jitter.

High jitter can downgrade the perceived ConnectionQuality to ConnectionQuality::Unstable.

Implementation

final double jitterThresholdPercent;