blockVpn property
If true, the reachability engine will flag or block connections if a VPN is detected.
This is useful for region-locked content or compliance requirements.
Implementation
final bool blockVpn;
If true, the reachability engine will flag or block connections if a VPN is detected.
This is useful for region-locked content or compliance requirements.
final bool blockVpn;