detectDnsHijack property

bool detectDnsHijack
final

If true, performs a check to detect potential DNS hijacking.

This involves comparing results from the system DNS with a trusted resolver. Note: This adds a small amount of latency to each check.

Implementation

final bool detectDnsHijack;