isVpnDetected property
True if the active interface is identified as a VPN or tunnel (e.g., 'tun0', 'utun').
Implementation
final bool isVpnDetected;
True if the active interface is identified as a VPN or tunnel (e.g., 'tun0', 'utun').
final bool isVpnDetected;