SecurityFlagsResult class abstract
- Implementers
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interfaceName ↔ String
-
getter/setter pair
- isDisposed → bool
-
Whether the underlying
Arcis disposed.no setterinherited - isDnsSpoofed ↔ bool
-
getter/setter pair
- isProxyDetected ↔ bool
-
getter/setter pair
- isVpnDetected ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isVpnDetected, bool? isDnsSpoofed, bool? isProxyDetected}) → SecurityFlagsResult -
Available on SecurityFlagsResult, provided by the SecurityFlagsResultCopyWith extension
Creates a copy of SecurityFlagsResult by modifying fields on the opaque pointer. -
dispose(
) → void -
Dispose the underlying
Arc.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
default_(
) → Future< SecurityFlagsResult> - Returns a "safe" default state: