packetLossPercent property
The percentage of samples that failed to return a response.
Any value above 0.0% indicates potential network congestion or hardware issues.
Implementation
final double packetLossPercent;
The percentage of samples that failed to return a response.
Any value above 0.0% indicates potential network congestion or hardware issues.
final double packetLossPercent;