NetworkStatus class

A high-level summary of the network's current state.

Available extensions

Constructors

NetworkStatus({required bool isConnected, required ConnectionQuality quality, required LatencyStats latencyStats, required String winnerTarget})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isConnected bool
True if the network is considered "connected" based on the CheckStrategy.
final
latencyStats LatencyStats
Detailed statistical breakdown of the connection's performance.
final
quality ConnectionQuality
The categorical quality of the connection (e.g., Excellent, Poor, Offline).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winnerTarget String
The label of the target that provided the fastest response in this check cycle.
final

Methods

copyWith({bool? isConnected, ConnectionQuality? quality, LatencyStats? latencyStats, String? winnerTarget}) NetworkStatus

Available on NetworkStatus, provided by the NetworkStatusCopyWith extension

Creates a copy of NetworkStatus with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override