winnerTarget property
The label of the target that provided the fastest response in this check cycle.
Implementation
final String winnerTarget;
The label of the target that provided the fastest response in this check cycle.
final String winnerTarget;