isEssential property

bool isEssential
final

If true, a failure of this specific target is considered a critical event.

Essential targets trigger the circuit breaker and can disqualify the network from being considered "connected" depending on the strategy.

Implementation

final bool isEssential;