TargetProtocol enum

Supported protocols for network reachability checks.

Inheritance
Available extensions

Values

tcp → const TargetProtocol

Transmission Control Protocol.

Performs a full 3-way handshake to ensure the port is open and accepting connections.

icmp → const TargetProtocol

Internet Control Message Protocol.

Sends an Echo Request (ping). Requires appropriate OS permissions.

http → const TargetProtocol

Hypertext Transfer Protocol.

Performs a GET or HEAD request and expects a successful status code (2xx/3xx).

https → const TargetProtocol

Secure Hypertext Transfer Protocol.

Performs an encrypted request over TLS. Validates the certificate chain by default.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TargetProtocol>
A constant List of the values in this enum, in order of their declaration.