NetworkReportImpl class

Implemented types
Available extensions
Annotations
  • @sealed

Properties

connectionType ConnectionType
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether the underlying Arc is disposed.
no setterinherited
move bool?
no getterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityFlagsResult SecurityFlagsResult
getter/setter pairoverride
status NetworkStatus
getter/setter pairoverride
targetReports List<TargetReport>
getter/setter pairoverride
timestampMs BigInt
getter/setter pairoverride

Methods

copyWith({BigInt? timestampMs, NetworkStatus? status, ConnectionType? connectionType, SecurityFlagsResult? securityFlagsResult, List<TargetReport>? targetReports}) NetworkReport

Available on NetworkReport, provided by the NetworkReportCopyWith extension

Creates a copy of NetworkReport by modifying fields on the opaque pointer.
dispose() → void
Dispose the underlying Arc.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited