SecurityAlert enum
Enum representing specific security alerts or policy violations.
This enum is used by the NetworkReachability.guard function to identify why a network-dependent action was blocked.
Values
- vpnDetected → const SecurityAlert
-
A VPN connection was detected on the active interface.
- dnsHijackDetected → const SecurityAlert
-
The resolved IP addresses from the system DNS do not match trusted resolvers.
- proxyDetected → const SecurityAlert
-
A system-level proxy server was detected (future implementation).
- unallowedInterface → const SecurityAlert
-
The active network interface is not in the allowed list.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecurityAlert> - A constant List of the values in this enum, in order of their declaration.