CircuitBreakerOpenException class
Thrown by the guard method when the circuit breaker is open due to repeated backend failures.
- Inheritance
-
- Object
- NetworkReachabilityException
- CircuitBreakerOpenException
Constructors
- CircuitBreakerOpenException(String message, {Duration? retryAfter})
-
Creates a new CircuitBreakerOpenException with the given
messageandretryAfter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message associated with this exception.
finalinherited
- retryAfter → Duration?
-
The duration to wait before attempting another request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts this object to a human-readable string representation.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited