PoorConnectionException class
Thrown by the guard method when the connection quality is below the required minimum.
- Inheritance
-
- Object
- NetworkReachabilityException
- PoorConnectionException
Constructors
- PoorConnectionException(String message)
-
Creates a new PoorConnectionException with the given
message.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts this object to a human-readable string representation.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited