QualityThresholdsCopyWith extension
Extension on QualityThresholds to provide an immutable way to copy the config.
Methods
-
copyWith(
{BigInt? excellent, BigInt? great, BigInt? good, BigInt? moderate, BigInt? poor}) → QualityThresholds -
Available on QualityThresholds, provided by the QualityThresholdsCopyWith extension
Creates a copy of QualityThresholds with the given fields replaced by the new values.