ResilienceConfigCopyWith extension
Extension on ResilienceConfig to provide an immutable way to copy the config.
Methods
-
copyWith(
{CheckStrategy? strategy, int? circuitBreakerThreshold, BigInt? circuitBreakerCooldownMs, int? numJitterSamples, double? jitterThresholdPercent, int? stabilityThershold, double? criticalPacketLossPrecent}) → ResilienceConfig -
Available on ResilienceConfig, provided by the ResilienceConfigCopyWith extension
Creates a copy of ResilienceConfig with the given fields replaced by the new values.