NetworkStatusCopyWith extension
Extension on NetworkStatus to provide an immutable way to copy the status summary.
Methods
-
copyWith(
{bool? isConnected, ConnectionQuality? quality, LatencyStats? latencyStats, String? winnerTarget}) → NetworkStatus -
Available on NetworkStatus, provided by the NetworkStatusCopyWith extension
Creates a copy of NetworkStatus with the given fields replaced by the new values.