QualityThresholds class
Defines the latency thresholds (in milliseconds) used to determine ConnectionQuality.
These values allow customizing what "Good" or "Poor" means for your specific application.
- Available extensions
Constructors
Properties
- excellent → BigInt
-
Latency at or below this value is considered
ConnectionQuality::Excellent.final - good → BigInt
-
Latency at or below this value is considered
ConnectionQuality::Good.final - great → BigInt
-
Latency at or below this value is considered
ConnectionQuality::Great.final - hashCode → int
-
The hash code for this object.
no setteroverride
- moderate → BigInt
-
Latency at or below this value is considered
ConnectionQuality::Moderate.final - poor → BigInt
-
Latency at or below this value is considered
ConnectionQuality::Poor. Anything higher is categorized asConnectionQuality::UnstableorConnectionQuality::Poor.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BigInt? excellent, BigInt? great, BigInt? good, BigInt? moderate, BigInt? poor}) → QualityThresholds -
Available on QualityThresholds, provided by the QualityThresholdsCopyWith extension
Creates a copy of QualityThresholds with the given fields replaced by the new values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
default_(
) → Future< QualityThresholds> - Provides sensible default latency thresholds for most mobile and web applications.
-
newInstance(
{required BigInt excellent, required BigInt great, required BigInt good, required BigInt moderate, required BigInt poor}) → Future< QualityThresholds> - Creates a new QualityThresholds instance.