circuitBreakerCooldownMs property
The cooldown period in milliseconds.
After this time, the circuit breaker transitions from 'Open' to 'Half-Open', allowing a trial check to see if the network has recovered.
Implementation
final BigInt circuitBreakerCooldownMs;