SecurityConfig class
Configuration for security-related network checks.
- Available extensions
Constructors
- SecurityConfig({required bool blockVpn, required bool detectDnsHijack})
-
const
Properties
- blockVpn → bool
-
If true, the reachability engine will flag or block connections if a VPN is detected.
final
- detectDnsHijack → bool
-
If true, performs a check to detect potential DNS hijacking.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? blockVpn, bool? detectDnsHijack}) → SecurityConfig -
Available on SecurityConfig, provided by the SecurityConfigCopyWith extension
Creates a copy of SecurityConfig with the given fields replaced by the new values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
default_(
) → Future< SecurityConfig>