CaptivePortalStatus class
The result of a captive portal detection probe.
Captive portals are commonly found on public WiFi networks (e.g., cafes, airports) where a login or "Terms of Service" acceptance is required before internet access is granted.
- Available extensions
Constructors
- CaptivePortalStatus({required bool isCaptivePortal, String? redirectUrl})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCaptivePortal → bool
-
True if the probe was redirected, indicating a captive portal is intercepting traffic.
final
- redirectUrl → String?
-
The destination URL of the redirection, if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isCaptivePortal, String? redirectUrl}) → CaptivePortalStatus -
Available on CaptivePortalStatus, provided by the CaptivePortalStatusCopyWith extension
Creates a copy of CaptivePortalStatus with the given fields replaced by the new values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override